"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SolanaSendSigner = void 0;
const platform_1 = require("../platform");
class SolanaSendSigner {
    _rpc;
    _chain;
    _keypair;
    _debug;
    constructor(_rpc, _chain, _keypair, _debug = false) {
        this._rpc = _rpc;
        this._chain = _chain;
        this._keypair = _keypair;
        this._debug = _debug;
    }
    chain() {
        return this._chain;
    }
    address() {
        return this._keypair.publicKey.toBase58();
    }
    async signAndSend(tx) {
        const { blockhash, lastValidBlockHeight } = await platform_1.SolanaPlatform.latestBlock(this._rpc, 'finalized');
        const txPromises = [];
        for (const txn of tx) {
            const { description, transaction } = txn;
            console.log(`Signing: ${description} for ${this.address()}`);
            if (this._debug) {
                console.log(transaction.signatures);
                console.log(transaction.feePayer);
                transaction.instructions.forEach((ix) => {
                    console.log('Program', ix.programId.toBase58());
                    console.log('Data: ', ix.data.toString('hex'));
                    console.log('Keys: ', ix.keys.map((k) => [k, k.pubkey.toBase58()]));
                });
            }
            transaction.partialSign(this._keypair);
            txPromises.push(this._rpc.sendRawTransaction(transaction.serialize(), {
                preflightCommitment: this._rpc.commitment,
            }));
        }
        const txids = await Promise.all(txPromises);
        // Wait for finalization
        for (const signature of txids) {
            await this._rpc.confirmTransaction({
                signature,
                blockhash,
                lastValidBlockHeight,
            });
        }
        return txids;
    }
}
exports.SolanaSendSigner = SolanaSendSigner;
//# sourceMappingURL=sendSigner.js.map